@@ -6,7 +6,7 @@
 #' @param choices Named vector. The option names and underyling values.
 #' @param selected String. The initially selected underyling value.
 #' @param multiple Boolean. Can multiple items be selected?
-#' @param color String. The color of the dropdown choices. Leave empty for the default color.
+#' @param color String. The color of the dropdown choices. Leave empty for the default color. Visit \url{http://materializecss.com/color.html} for a list of available colors. \emph{This input requires using color hex codes, rather than the word form. E.g., '#ef5350', rather than 'red lighten-1'.}
 #' @examples
 #' material_dropdown(
 #'   input_id = "example_dropdown",
@@ -18,7 +18,7 @@
 #'   ),
 #'   selected = c("c"),
 #'   multiple = FALSE,
-#'   color = "blue"
+#'   color = "#ef5350"
 #' )
 material_dropdown <- function(input_id, label, choices = NULL, selected = NULL, multiple = NULL, color = NULL){
   
@@ -31,7 +31,7 @@ material_dropdown <- function(input_id, label, choices = NULL, selected = NULL,
             paste0(
               '
               #shiny-material-dropdown-', input_id, ' ul.dropdown-content.select-dropdown li span {
-              color: red;
+              color: ', color, ';
                }
               '
             )
